@@ -92,6 +92,44 @@ class Product(object):
                 return link
         return None
 
+    @property
+    def ratings(self):
+        ratings = [0, 0, 0, 0, 0]
+        reviews_div = self.soup.find('div', class_='reviews')
+        if reviews_div:
+            for rating, rating_class in [
+                (4, 'histoRowfive'),
+                (3, 'histoRowfour'),
+                (2, 'histoRowthree'),
+                (1, 'histoRowtwo'),
+                (0, 'histoRowone'),
+            ]:
+                rating_div = reviews_div.find('div', class_=rating_class)
+                if rating_div:
+                    # no ratings means this won't exist
+                    tag = rating_div.find('div', class_='histoCount')
+                    if tag:
+                        value = tag.string
+                        value = value.replace(',', '')
+                        ratings[rating] = int(value)
+            return ratings
+
+        table = self.soup.find('table', id='histogramTable')
+        if table:
+            for rating, row in zip([4,3,2,1,0], table.find_all('tr', class_='a-histogram-row')):
+                # get the third td tag
+                children = [child for child in row.find_all('td', recursive=False)]
+                td = children[2]
+                data = td.find('span', class_=False)
+                if data:
+                    # number could have , in it which fails during int conversion
+                    value = data.string
+                    value = value.replace(',', '')
+                    ratings[rating] = int(value)
+            return ratings
+
+        return ratings
+
     def to_dict(self):
         d = {}
         # print the object as an xml string, parse the string to a dict
